"""High level API for letters."""
from typing import Optional

from pydantic import BaseModel

from .message import Message, MessageEnvelope


class Address(BaseModel):
    """Letter recipient address."""

    name: Optional[str] = None
    organization: Optional[str] = None
    street: Optional[str] = None
    city: Optional[str] = None
    state_or_province: Optional[str] = None
    postal_code: Optional[str] = None
    country_code: Optional[str] = None


class Letter(Message):
    """Provide a structure for letter message."""

    recipient: Address
    file: str

    render_fields = ()


class LetterEnvelope(MessageEnvelope[Letter]):
    """Provide a structure for letter envelope."""
